# MKFOL

Module untuk membuat folder berdasarkan template

## Latar Belakang

Lelah membuat folder-folder yang sama berulang kali

## Installation

Via git glone

```bash
git clone https://github.com/SulthanAbiyyu/mkfol
```

Via pip

```bash
masih belum dipublish hehe
```
